@@ -4,8 +4,9 @@ import os
 import subprocess
 import sys
 from datetime import datetime, timedelta, timezone
-from typing import List, Optional
+from typing import List, NamedTuple, Optional
 
+import inject
 import structlog
 
 from db_contrib_tool.config import SetupReproEnvConfig
@@ -35,29 +36,55 @@ def setup_logging(debug: bool = False) -> None:
     structlog.configure(logger_factory=structlog.stdlib.LoggerFactory())
 
 
+class BisectParameters(NamedTuple):
+    """
+    Parameters for bisect command.
+
+    * branch: git branch name.
+    * lookback: lookback count.
+    * variant: build variant name.
+    * script: path to user script.
+    * python_installation: path to python executable.
+    * debug: whether debugging should be enabled or not.
+    * evergreen_config: path to evergreen config file.
+    """
+
+    branch: str
+    lookback: int
+    variant: str
+    script: str
+    python_installation: str
+    debug: bool = False
+    evergreen_config: Optional[str] = None
+
+
+class VersionInfo(NamedTuple):
+    """
+    Brief information about a version.
+
+    * revision: revision string from GitHub.
+    * version_id: unique ID of the version provided by Evergreen.
+    """
+
+    revision: str
+    version_id: str
+
+
 class Bisect:
     """Main class for the Bisect subcommand."""
 
+    @inject.autoparams()
     def __init__(
         self,
-        branch: str,
-        lookback: int,
-        variant: str,
-        script: str,
-        python_installation: str,
-        evergreen_config: Optional[str] = None,
-        debug: bool = False,
+        params: BisectParameters,
+        setup_repro_env_config: SetupReproEnvConfig,
     ):
         """Initialize."""
-        setup_logging(debug)
-        self.branch = branch
-        self.lookback = lookback
-        self.variant = variant
-        self.script = script
-        self.python_installation = python_installation
-        self.evergreen_config = evergreen_config
-        self.evg_api = evergreen_conn.get_evergreen_api(evergreen_config)
-        self.evg_service = EvergreenService(self.evg_api, SetupReproEnvConfig.empty_config())
+        setup_logging(params.debug)
+        self.params = params
+        self.evergreen_config = params.evergreen_config
+        self.evg_api = evergreen_conn.get_evergreen_api(params.evergreen_config)
+        self.evg_service = EvergreenService(self.evg_api, setup_repro_env_config)
 
     @staticmethod
     def _teardown_test_env(version: str) -> None:
@@ -84,9 +111,9 @@ class Bisect:
                 [
                     "bash",
                     SETUP_TEST_ENV_SH,
-                    self.python_installation,
+                    self.params.python_installation,
                     self.evergreen_config if self.evergreen_config else "",
-                    self.variant,
+                    self.params.variant,
                     version,
                 ],
                 check=True,
@@ -100,9 +127,9 @@ class Bisect:
                     [
                         "bash",
                         SETUP_TEST_ENV_SH,
-                        self.python_installation,
+                        self.params.python_installation,
                         self.evergreen_config if self.evergreen_config else "",
-                        self.variant,
+                        self.params.variant,
                         version,
                     ],
                     check=True,
@@ -120,24 +147,24 @@ class Bisect:
         :return: Return code of script run.
         """
         return subprocess.run(
-            ["bash", RUN_USER_SCRIPT_SH, version, self.script], check=False
+            ["bash", RUN_USER_SCRIPT_SH, version, self.params.script], check=False
         ).returncode
 
-    def _test_version_with_script(self, version: str) -> bool:
+    def _test_version_with_script(self, version_id: str) -> bool:
         """
         Test the given version with the user provided script.
 
-        :param version: Version reference.
+        :param version_id: Version reference.
         :return: Whether succeeded or not.
         """
-        self._setup_test_env(version)
-        success = self._run_user_script(version)
-        self._teardown_test_env(version)
+        self._setup_test_env(version_id)
+        success = self._run_user_script(version_id)
+        self._teardown_test_env(version_id)
         return success == 0
 
-    def bisect(self, versions: List[str]) -> Optional[str]:
+    def bisect(self, versions: List[VersionInfo]) -> Optional[VersionInfo]:
         """
-        Bisect to find latest passing version assuming ordered by oldest to latest version.
+        Bisect to find the latest passing version assuming ordered by oldest to the latest version.
 
         :param versions: List of versions that have binaries.
         :return: Found version or None.
@@ -145,20 +172,22 @@ class Bisect:
         if len(versions) == 0:
             return None
         midpoint = len(versions) // 2
-        success = self._test_version_with_script(versions[midpoint])
+        version_info = versions[midpoint]
+
+        success = self._test_version_with_script(version_info.version_id)
         # if success, keep checking right
         if success:
             LOGGER.info(
                 "Version passed user script.",
-                version=versions[midpoint],
+                version=versions[midpoint].revision,
             )
-            return self.bisect(versions[midpoint + 1 :]) or versions[midpoint]
-        # if fail, keep checking left
+            return self.bisect(versions[midpoint + 1 :]) or version_info
+        # if failure, keep checking left
         else:
-            LOGGER.info("Version failed user script.", version=versions[midpoint])
+            LOGGER.info("Version failed user script.", version=version_info.revision)
             return self.bisect(versions[0:midpoint])
 
-    def find_versions_with_binaries(self) -> List[str]:
+    def find_versions_with_binaries(self) -> List[VersionInfo]:
         """
         Find versions that have binaries for the user provided variant in the lookback period.
 
@@ -166,15 +195,15 @@ class Bisect:
         """
         versions_with_binaries = []
         for version in self.evg_api.versions_by_project_time_window(
-            project_id=f'mongodb-mongo-{"" if self.branch == "master" else "v"}{self.branch}',
+            project_id=f'mongodb-mongo-{"" if self.params.branch == "master" else "v"}{self.params.branch}',
             before=datetime.now(timezone.utc),
-            after=datetime.now(timezone.utc) - timedelta(self.lookback),
+            after=datetime.now(timezone.utc) - timedelta(self.params.lookback),
         ):
             urls = self.evg_service.get_compile_artifact_urls(
-                version, self.variant, ignore_failed_push=True
+                version, self.params.variant, ignore_failed_push=True
             )
             if urls is not None and urls.urls.get("Artifacts") and urls.urls.get("Binaries"):
-                versions_with_binaries.append(version.revision)
+                versions_with_binaries.append(VersionInfo(version.revision, version.version_id))
 
         versions_with_binaries.reverse()
         return versions_with_binaries
@@ -193,9 +222,9 @@ class Bisect:
         if not versions_with_binaries:
             LOGGER.info(
                 "No versions with binaries found for given branch, variant & lookback period.",
-                branch=self.branch,
-                variant=self.variant,
-                lookback=self.lookback,
+                branch=self.params.branch,
+                variant=self.params.variant,
+                lookback=self.params.lookback,
             )
             return True
 
