@@ -10,11 +10,7 @@ import structlog
 from evergreen import Version
 from requests.exceptions import HTTPError
 
-from db_contrib_tool.config import (
-    SETUP_REPRO_ENV_CONFIG_FILE,
-    DownloadTarget,
-    SetupReproEnvConfig,
-)
+from db_contrib_tool.config import SETUP_REPRO_ENV_CONFIG_FILE, DownloadTarget, SetupReproEnvConfig
 from db_contrib_tool.services.evergreen_service import EvergreenService
 from db_contrib_tool.services.git_service import GitService
 from db_contrib_tool.services.platform_service import PlatformService
@@ -310,7 +306,7 @@ class ArtifactDiscoveryService:
         Scan through evergreen version to find the most recent artifacts to download.
 
         :param mongo_project: Name of mongo project in evergreen.
-        :param buildvariant_name: Name of build variant to download from.
+        :param requested_variant: Name of build variant to download from.
         :param target: Details about what platform/edition/architecture to target.
         :param ignore_failed_push: Can a failed push task be ignored.
         :param starting_commit: Only match versions previous to this commit.
@@ -367,7 +363,7 @@ class ArtifactDiscoveryService:
 
         This will infer the platform if it is not specified.
 
-        :param mongo_version: Mongo version being targetted.
+        :param mongo_version: Mongo version being targeted.
         :param target: Download target to use as a base.
         :return: Download target to use.
         """
